@@ -1,5 +1,6 @@
 import  extraEncodings
 import random
+import time
 countingstuff = 0
 #Gen2
 Encodeable_letters = r'''aAbBcCdDeEfFgGhHiIjJkKlLmMnNoOpPqQrRsStTuUvVwWxXyYzZ1234567890!@\#$%^&*()`~-=_+[]}{'\";:| ,.<>/?'''
@@ -192,12 +193,5 @@ def GTX2Code(Character_to_decode):
         print(ResultStr,end='')
 #Example below
 #LTF64Code(r'Fire balls')
-#!!!!!----------!!!!!!
-#Beyond this line are items that are not available 
-#in the pre made encoder and are only to help you make your own encoders
-# and stuff
-#!!!!!!!--------------!!!!!
-Madeencodings = 0
-
-
-
+time.sleep(0.3)
+print('Initialization:ciphers.py,Complete')
\ No newline at end of file
