@@ -5,6 +5,7 @@ import  extraEncodings.ciphers
 from  extraEncodings.ciphers import *
 import  extraEncodings.encodingsGui
 from extraEncodings.encodingsGui import *
+print('Initialization:encodings.py,Complete')
 #functions to encode and decode
 def encodeto():
     entype = input("Which encoding?")
@@ -75,9 +76,9 @@ def coder():
         if x == "GUI".upper():
             startGUI()
         if  x == "secrets".upper():
-            print('''       地下深くで約束が破られます。
-            古代の確執は壊れて揺れます。
-            地球の中から火をつけます。
-            地獄を永  遠に燃やす ''')
+            print(''':>9~;9cW;5C:/9~;9cCW;5C:/9~;9''')
+time.sleep(0.5)
+print('Initialization:encodings.py,Complete')
+print('Finshed!')
 if __name__ == "__main__":
     coder()
